# Confumo — Python config framework
# Copyright (C) 2025 Aaron Colichia
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# See <https://www.gnu.org/licenses/> for details.

from __future__ import annotations

from .confumo import Confumo

try:
    from ._version import version as __version__
except Exception:  # pragma: no cover
    __version__ = "0.0.0"
